import 'package:unittest/unittest.dart';
import 'package:unittest/html_config.dart';
import 'dart:html';
import 'package:iskernel_html_tablesorter/html_tablesorter.dart';

void group_constructor_tests()
{
  group
  (
      'Constructor group - ',
      ()
      {
        test
        (
            "Constructor creates TableSorter object",
            ()
            {
              TableSorter sorter = new TableSorter("#projectTable");  
              expect
              (
                  sorter,
                  isNotNull                  
              ); 
            }
        );        
      }
  );
}

void group_enableSorting_tests()
{
  group 
  (
    "enableSorting group - ",
    ()
    {
      test
      (
        "enableSorting(true) adds links to table headers",  
        ()
        {
          TableSorter sorter = new TableSorter("#projectTable");
          sorter.enableSorting(true);
          RegExp hasLinks = new RegExp(
              '<tr><th><a href="#">Name</a></th><th><a href="#">Age</a></th>'); 
          bool result = sorter.table.outerHtml.contains(hasLinks);
          sorter.enableSorting(false);
          expect
          (
              result,
              isTrue
          );
        }
      );
      test
      (
        "enableSorting(false) removes the links",  
        ()
        {
          String noLinks 
          = '<tr><th>Name</th><th>Age</th>';
          RegExp hasLinks = new RegExp(
            '<tr><th><a href="#">Name</a></th><th><a href="#">Age</a></th>');            
          TableSorter sorter = new TableSorter("#projectTable");
          sorter.table.tHead.innerHtml = noLinks;
          
          sorter.enableSorting(true);
          sorter.enableSorting(false);
         
          expect
          (
              sorter.table.outerHtml.contains(hasLinks),
              isFalse
          );
        }
      );
    }
  );
}

void group_getTable_tests()
{
  group
  (
      'getTable group - ',
      ()
      {
        test
        (
            "getTable returns the table if TableSorter instantiated",
            ()
            {
              TableSorter sorter = new TableSorter("#projectTable");  
              TableElement element = query("#projectTable");
              expect
              (
                  sorter.table,
                  equals(element)                  
              ); 
            }
        );  
      }
  );
}

void main()
{
  useHtmlConfiguration();
  group_constructor_tests();
  group_enableSorting_tests();
  group_getTable_tests();
}